pub struct ApkListingsListResponse {
pub kind: Option<String>,
pub listings: Option<Vec<ApkListing>>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- apklistings list edits (response)
Fields
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “androidpublisher#apkListingsListResponse”.
listings: Option<Vec<ApkListing>>no description provided