Struct google_androidpublisher2::api::ListingsListResponse[][src]

pub struct ListingsListResponse {
    pub kind: Option<String>,
    pub listings: Option<Vec<Listing>>,
}

There is no detailed description.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

kind: Option<String>

Identifies what kind of resource this is. Value: the fixed string “androidpublisher#listingsListResponse”.

listings: Option<Vec<Listing>>

no description provided