Struct google_androidpublisher2::api::InappproductsListResponse [−][src]
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list inappproducts (response)
Fields
inappproduct: Option<Vec<InAppProduct>>no description provided
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “androidpublisher#inappproductsListResponse”.
page_info: Option<PageInfo>no description provided
token_pagination: Option<TokenPagination>no description provided